@@ -1,5 +1,5 @@
 package WebService::Bonusly;
-$WebService::Bonusly::VERSION = '0.151580';
+$WebService::Bonusly::VERSION = '0.153420';
 use v5.14;
 use Moose;
 use Furl;
@@ -168,6 +168,7 @@ sub _build_values {
 }
 
 
+
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -182,7 +183,7 @@ WebService::Bonusly - A handy library for accessing the Bonus.ly API
 
 =head1 VERSION
 
-version 0.151580
+version 0.153420
 
 =head1 SYNOPSIS
 
@@ -224,6 +225,7 @@ version 0.151580
     $res = $bonusly->users->delete( id => '...' );
     $res = $bonusly->users->get( id => '...' );
     $res = $bonusly->users->list;
+    $res = $bonusly->users->me;
     $res = $bonusly->users->redemptions;
     $res = $bonusly->users->update( id => '...' );
         
@@ -392,6 +394,12 @@ Required Parameters: C<id>
 
 Performs a GET against C</api/v1/users> at bonus.ly.
 
+=head3 me
+
+    $res = $bonusly->users->me;
+
+Performs a GET against C</api/v1/users/me> at bonus.ly.
+
 =head3 redemptions
 
     $res = $bonusly->users->redemptions;
@@ -428,6 +436,19 @@ Required Parameters: C<id>
 
 Performs a GET against C</api/v1/values> at bonus.ly.
 
+=head1 DEVELOPMENT
+
+If you are interested in helping develop this library. Please check it out from github. See L<https://github.com/zostay/WebService-Bonusly>. The library is automatically generated from a script named F<apigen.pl>. To build the library you will need to install L<Dist::Zilla> and run:
+
+    dzil authordeps | cpanm
+    dzil build
+
+Instead of running the "dzil build" command you may also run:
+
+    ./apigen.pl
+
+The templates for generating the code are found in F<tmpl>.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
